<?php
// Register a fundraising campaigns block for Gutenberg.
add_filter( 'rwmb_meta_boxes', function( $meta_boxes ) {
	if (!class_exists('Give')) {
		return false;
	}

	// Does the user want category?
	$enable_category = give_is_setting_enabled( give_get_option( 'categories', 'disabled' ) );

	// Does the user want tag?
	$enable_tag = give_is_setting_enabled( give_get_option( 'tags', 'disabled' ) );

	// get fundraising category
	$category_options = array();
	if ($enable_category) {
		$categories =  get_terms( array(
			'taxonomy' => 'give_forms_category',
			'hide_empty' => false,
		) );
	
		foreach ($categories as $category) {
			$category_options[$category->term_id] = $category->name;
		}
	}

	// get fundraising topcis
	$topcis_options = array();
	if ($enable_tag) {
		$topcis =  get_terms( array(
			'taxonomy' => 'give_forms_tag',
			'hide_empty' => false,
		) );
	
		foreach ($topcis as $topic) {
			$topcis_options[$topic->term_id] = $topic->name;
		}	
	}
	
	$meta_boxes[] = [
		'title' => esc_html__('Fundraisers', 'campoal-tapo'),
		'id'    => 'fundraising',
		'type'  => 'block', // Important.
		'mode' 	=> 'edit',
		// 'icon'  => 'awards', // Or you can set a custom SVG if you don't like Dashicons
		'icon'  => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><!-- Font Awesome Pro 5.15.4 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) --><defs><style>.fa-secondary{opacity:.4}</style></defs><path d="M256 416c114.9 0 208-93.1 208-208S370.9 0 256 0 48 93.1 48 208s93.1 208 208 208zM233.8 97.4V80.6A16.56 16.56 0 0 1 250.4 64h11.1a16.56 16.56 0 0 1 16.6 16.6v17a78.84 78.84 0 0 1 43 15.4 11.21 11.21 0 0 1 1.2 17.1L306 145.6c-3.8 3.7-9.5 3.8-14 1a32.91 32.91 0 0 0-17.8-5.1h-38.9c-9 0-16.3 8.2-16.3 18.3 0 8.2 5 15.5 12.1 17.6l62.3 18.7c25.7 7.7 43.7 32.4 43.7 60.1 0 34-26.4 61.5-59.1 62.4v16.8a16.56 16.56 0 0 1-16.6 16.6h-11.1a16.56 16.56 0 0 1-16.6-16.6v-17a78.84 78.84 0 0 1-43-15.4 11.21 11.21 0 0 1-1.2-17.1l16.3-15.5c3.8-3.7 9.5-3.8 14-1a32.91 32.91 0 0 0 17.8 5.1h38.9c9 0 16.3-8.2 16.3-18.3 0-8.2-5-15.5-12.1-17.6l-62.3-18.7c-25.7-7.7-43.7-32.4-43.7-60.1.1-34 26.4-61.5 59.1-62.4z" class="fa-secondary"/><path d="M218.4 219.9l62.3 18.7c7.1 2.1 12.1 9.4 12.1 17.6 0 10.1-7.3 18.3-16.3 18.3h-38.9a32.91 32.91 0 0 1-17.8-5.1c-4.5-2.8-10.2-2.7-14 1l-16.3 15.5a11.21 11.21 0 0 0 1.2 17.1 78.84 78.84 0 0 0 43 15.4v17a16.56 16.56 0 0 0 16.6 16.6h11.1a16.56 16.56 0 0 0 16.6-16.6v-16.8c32.7-.9 59.1-28.4 59.1-62.4 0-27.7-18-52.4-43.7-60.1l-62.3-18.7c-7.1-2.1-12.1-9.4-12.1-17.6 0-10.1 7.3-18.3 16.3-18.3h38.9a32.91 32.91 0 0 1 17.8 5.1c4.5 2.8 10.2 2.7 14-1l16.3-15.5a11.21 11.21 0 0 0-1.2-17.1 78.84 78.84 0 0 0-43-15.4v-17A16.56 16.56 0 0 0 261.5 64h-11.1a16.56 16.56 0 0 0-16.6 16.6v16.8c-32.7.9-59 28.4-59.1 62.4 0 27.7 18 52.4 43.7 60.1zM480 352h-32.5a242.37 242.37 0 0 1-73 64h63.8c5.3 0 9.6 3.6 9.6 8v16c0 4.4-4.3 8-9.6 8H73.6c-5.3 0-9.6-3.6-9.6-8v-16c0-4.4 4.3-8 9.6-8h63.8a243.57 243.57 0 0 1-73-64H32a32 32 0 0 0-32 32v96a32 32 0 0 0 32 32h448a32 32 0 0 0 32-32v-96a32 32 0 0 0-32-32z" class="fa-primary"/></svg>',
		'category' => 'campoal',
		'context' => 'side', // The block settings will be available on the right sidebar.
		'supports' => [
			'align' => ['wide', 'full'],
		],
		// 'render_callback' => 'conikal_featured_posts_shortcode',
		'render_template' => plugin_dir_path( __FILE__ ) . 'template.php', // The PHP template that renders the block.
		// 'enqueue_style'   => plugin_dir_path( __FILE__ ) . 'style.css', // CSS file for the block.

		// Now register the block fields.
		'fields' => [
			[
				'type' 			=> 'text',
				'id'   			=> 'title',
				'name' 			=> esc_html__('Section Title', 'campoal-tapo'),
				'placeholder'   => esc_html__('Enter a title', 'campoal-tapo'),
			],
			[
				'type' 			=> 'button_group',
				'id'   			=> 'title_alignment',
				'name' 			=> esc_html__('Title Alignment', 'campoal-tapo'),
				'options' => array(
					'left' 			=> '<span class="dashicons dashicons-editor-alignleft"></span>',
					'center' 		=> '<span class="dashicons dashicons-editor-aligncenter"></span>',
					'right' 		=> '<span class="dashicons dashicons-editor-alignright"></span>',
				),
				'inline'   => true,
			],
			[
				'type' => 'select',
				'id'   => 'type',
				'name' => esc_html__('Type', 'campoal-tapo'),
				'options' => array(
					'recent' 			=> esc_html__('Recent', 'campoal-tapo'),
					'by_id' 			=> esc_html__('Campaigns by IDs', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 			=> 'number',
				'id'   			=> 'show',
				'name' 			=> esc_html__('Show', 'campoal-tapo'),
				'placeholder'	=> esc_html__('Number of campaigns display', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'column',
				'name' => esc_html__('Column', 'campoal-tapo'),
				'options' => array(
					'two' 	=> '2',
					'three' => '3',
					'four' 	=> '4',
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'orderby',
				'name' => 'Order by',
				'options' => array(
					'none' 			=> esc_html__('None', 'campoal-tapo'),
					'views' 		=> esc_html__('Views', 'campoal-tapo'),
					'ID' 			=> esc_html__('ID', 'campoal-tapo'),
					'author' 		=> esc_html__('Author', 'campoal-tapo'),
					'title' 		=> esc_html__('Title', 'campoal-tapo'),
					'name' 			=> esc_html__('Name', 'campoal-tapo'),
					'date' 			=> esc_html__('Date', 'campoal-tapo'),
					'modified' 		=> esc_html__('Modified', 'campoal-tapo'),
					'rand' 			=> esc_html__('Random', 'campoal-tapo'),
					'comment_count'	=> esc_html__('Comment count', 'campoal-tapo'),
				),
				'placeholder'     	=> esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'order',
				'name' => esc_html__('Order', 'campoal-tapo'),
				'options' => array(
					'ASC' 	=> esc_html__('Ascending', 'campoal-tapo'),
					'DESC' 	=> esc_html__('Descending', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 		=> 'select',
				'id'   		=> 'categories',
				'name' 		=> esc_html__('Categories', 'campoal-tapo'),
				'options' 	=> $category_options,
				'multiple'        => true,
				'select_all_none' => true,
				'placeholder'     => esc_html__('All', 'campoal-tapo'),
			],
			[
				'type' 		=> 'select',
				'id'   		=> 'tags',
				'name' 		=> esc_html__('Tags', 'campoal-tapo'),
				'options' 	=> $topcis_options,
				'multiple'        => true,
				'select_all_none' => true,
				'placeholder'     => esc_html__('All', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'carousel',
				'name' => esc_html__('Carousel', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'hover',
				'name' => esc_html__('Shadow', 'campoal-tapo'),
			],
			[
				'type' 			=> 'text',
				'id'   			=> 'form_ids',
				'name' 			=> esc_html__('Donation Form IDs', 'campoal-tapo'),
				'placeholder'   => esc_html__('Optional (separated by commas)', 'campoal-tapo'),
			],
		],
	];

	return $meta_boxes;
} );
