<?php
// Register a supporter list block for Gutenberg.
add_filter( 'rwmb_meta_boxes', function( $meta_boxes ) {

	// Type select options
	$type_arg = array(
        'supporters' => esc_html__('Supporters', 'campoal-tapo')
    );
    if (class_exists('Give')) {
        $type_arg['donors'] = esc_html__('Donors', 'campoal-tapo');
    }

	$meta_boxes[] = [
		'title' => esc_html__('Supporters and Donors', 'campoal-tapo'),
		'id'    => 'supporters-list',
		'type'  => 'block', // Important.
		'mode' 	=> 'edit',
		// 'icon'  => 'awards', // Or you can set a custom SVG if you don't like Dashicons
		'icon'  => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 640 512"><!-- Font Awesome Pro 5.15.4 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) --><defs><style>.fa-secondary{opacity:.4}</style></defs><path d="M480 256a96 96 0 1 0-96-96 96 96 0 0 0 96 96zm48 32h-3.8c-13.9 4.8-28.6 8-44.2 8s-30.3-3.2-44.2-8H432c-20.4 0-39.2 5.9-55.7 15.4 24.4 26.3 39.7 61.2 39.7 99.8v38.4c0 2.2-.5 4.3-.6 6.4H592a48 48 0 0 0 48-48 111.94 111.94 0 0 0-112-112z" class="fa-secondary"/><path d="M192 256A112 112 0 1 0 80 144a111.94 111.94 0 0 0 112 112zm76.8 32h-8.3a157.53 157.53 0 0 1-68.5 16c-24.6 0-47.6-6-68.5-16h-8.3A115.23 115.23 0 0 0 0 403.2V432a48 48 0 0 0 48 48h288a48 48 0 0 0 48-48v-28.8A115.23 115.23 0 0 0 268.8 288z" class="fa-primary"/></svg>',
		'category' => 'campoal',
		'context' => 'side', // The block settings will be available on the right sidebar.
		'supports' => [
			'align' => ['wide', 'full'],
		],
		// 'render_callback' => 'conikal_featured_posts_shortcode',
		'render_template' => plugin_dir_path( __FILE__ ) . 'template.php', // The PHP template that renders the block.
		// 'enqueue_style'   => plugin_dir_path( __FILE__ ) . 'style.css', // CSS file for the block.

		// Now register the block fields.
		'fields' => [
			[
				'type' 			=> 'text',
				'id'   			=> 'title',
				'name' 			=> esc_html__('Section Title', 'campoal-tapo'),
				'placeholder'   => esc_html__('Enter a title', 'campoal-tapo'),
			],
			[
				'type' 			=> 'button_group',
				'id'   			=> 'title_alignment',
				'name' 			=> esc_html__('Title Alignment', 'campoal-tapo'),
				'options' => array(
					'left' 			=> '<span class="dashicons dashicons-editor-alignleft"></span>',
					'center' 		=> '<span class="dashicons dashicons-editor-aligncenter"></span>',
					'right' 		=> '<span class="dashicons dashicons-editor-alignright"></span>',
				),
				'inline'   => true,
			],
			[
				'type' 			=> 'post',
				'post_type'		=> array('petition'),
				'id'   			=> 'id',
				'name' 			=> esc_html__('Petition or Form ID', 'campoal-tapo'),
				'placeholder'   => esc_html__('Set an petition ID for supporters type and Form ID for donors type.', 'campoal-tapo'),
				'field_type' 	=> 'select_advanced',
			],
			[
				'type' => 'select',
				'id'   => 'type',
				'name' => esc_html__('Type', 'campoal-tapo'),
				'options' => $type_arg,
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'style',
				'name' => esc_html__('Style', 'campoal-tapo'),
				'options' => array(
					'avatar'		=> esc_html__('Avatar', 'campoal-tapo'),
					'grid' 			=> esc_html__('Grid', 'campoal-tapo'),
					'list' 			=> esc_html__('List', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 			=> 'number',
				'id'   			=> 'number',
				'name' 			=> esc_html__('Show', 'campoal-tapo'),
				'placeholder'	=> esc_html__('Number of supporters display', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'size',
				'name' => 'Size',
				'options' => array(
					'mini' 			=> esc_html__('Mini', 'campoal-tapo'),
					'tiny' 		=> esc_html__('Tiny', 'campoal-tapo'),
					'small' 	=> esc_html__('Small', 'campoal-tapo'),
					'medium' 			=> esc_html__('Medium', 'campoal-tapo'),
					'large' 		=> esc_html__('Large', 'campoal-tapo'),
					'big' 		=> esc_html__('Big', 'campoal-tapo'),
					'huge' 			=> esc_html__('Huge', 'campoal-tapo'),
					'massive' 			=> esc_html__('Massive', 'campoal-tapo'),
				),
				'placeholder'     	=> esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'column',
				'name' => esc_html__('Column', 'campoal-tapo'),
				'options' => array(
					'one'	=> '1',
					'two' 	=> '2',
					'three' => '3',
					'four' 	=> '4',
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'hide_amount',
				'name' => esc_html__('Hide donation amount', 'campoal-tapo'),
			],
		],
	];
	return $meta_boxes;
} );
