<?php 

/**
* Get client ip address
*
* @since Campoal Tapo 1.0.0
*/
if (!function_exists('conikal_get_client_ip')) :    
    function conikal_get_client_ip() {
        //Get the IP of the person registering
		$ip = $_SERVER['REMOTE_ADDR'];

		// If there's forwarding going on...
		if ( isset( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
			$http_x_headers = explode( ',', $_SERVER['HTTP_X_FORWARDED_FOR'] );
			$ip             = sanitize_text_field( $http_x_headers[0] );
		}
        return $ip;
    }
endif;


/**
* Get client's location by GeoIP
*
* @since Campoal Tapo 1.4.3
*/
if (!function_exists('conikal_client_geoip_info')) :
	function conikal_client_geoip_info() {
		if (function_exists('geoip_detect2_get_info_from_ip') && function_exists('conikal_get_client_ip')) {
	    	$client_geoip = geoip_detect2_get_info_from_ip(conikal_get_client_ip(), NULL);
		} else {
		    $client_geoip = false;
		}

		return $client_geoip;
	}
endif;


/**
* Display custom sign label button
* @since Campoal 2.4.1
*/
if( !function_exists('conikal_custom_sign_label_button') ):
	function conikal_custom_sign_label_button($petition_id, $default_label = false) {
		global $campoal_options;
		$sign_button_text = isset($campoal_options['conikal_sign_button_text_field']) ? $campoal_options['conikal_sign_button_text_field'] : '';
		
		// get custom sign button label
		$custom_button_label        = get_post_meta($petition_id, 'petition_sign_button_label', true);
		$sign_button_text           = !empty($custom_button_label) ? $custom_button_label : $sign_button_text;
        if (!empty($default_label)) {
            $sign_button_text = $default_label;
        } else if (!empty($sign_button_text)) {
            $sign_button_text = __('Sign', 'campoal-tapo');
        }
        
		return $sign_button_text;
	}
endif;


/**
* Get default page by template
*
* @since Campoal Tapo 1.0.0
*/
if (!function_exists('conikal_get_page_id_by_template')) :  
    function conikal_get_page_id_by_template($template = false) {
        if ($template != false) {
            $template_args = array(
                'post_type' => 'page',
                'post_status' => 'publish',
                'meta_key' => '_wp_page_template',
                'meta_value' => $template
            );

            $template_query = get_pages($template_args);

            if (!empty($template_query)) {
                foreach ($template_query as $page) {
                    $result = $page->ID;
                }
            } else {
                $result = false;
            }

        } else {
            $result = '';
        }
        return $result;
    }
endif;

/**
* Get all page
*
* @since Campoal Tapo 1.0.0
*/
if (!function_exists('conikal_get_all_pages')) : 
    function conikal_get_all_pages($args = array()) {
        if (empty($args)) {
            $args = array(
                'sort_order' => 'asc',
                'sort_column' => 'post_title',
                'post_type' => 'page',
                'post_status' => 'publish',
            );
        }
        $query_pages = get_pages($args);
        $results = array();

        foreach ($query_pages as $page) {
            $results[$page->ID] = $page->post_title;
        }

        return $results;
    }
endif;

/**
 * Add custom profile field
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_add_custom_profile_fields') ):
    function conikal_add_custom_profile_fields($profile_fields) {
        $profile_fields['avatar'] = esc_html__('Avatar URL');

        return $profile_fields;
    }
endif;
add_filter('user_contactmethods', 'conikal_add_custom_profile_fields');


/**
 * Get petition thumbnail
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_get_petition_thumbnail')) :
    function conikal_get_petition_thumbnail($id, $size = 'conikal-petition-thumbnail', $placeholder = 'thumbnail-small') {
        $post_type = get_post_type($id);
        if ($post_type == 'give_forms') {
            $prefix = '_give_';
        } else {
            $prefix = 'petition_';
        }

        $gallery = get_post_meta($id, $prefix . 'gallery', true);
        $images = conikal_get_gallery_images($gallery);
        $video_thumb_size = ($size == 'conikal-petition-medium' || $size == 'conikal-petition-medium-retina') ? 'thumb' : 'thumb_small';
        $thumb = get_post_meta($id, $prefix . $video_thumb_size, true);

        if(has_post_thumbnail($id)) {
            $thumb_id = get_post_thumbnail_id($id);
            $thumbnail = wp_get_attachment_image_src($thumb_id, $size, true);
            $thumbnail = $thumbnail[0];
        } elseif ($thumb) {
            $thumbnail = $thumb;
        } elseif ($gallery) {
            $thumbnail = $images[1];
        } else {
            if ($placeholder) {
                $thumbnail = get_template_directory_uri() . '/images/' . $placeholder . '.svg';
            } else {
                $thumbnail = false;
            }
        }

        return $thumbnail;
    }
endif;

/**
 * Short code column options
 *
 * @since Campoal Tapo 1.8.9
 */
if( !function_exists('conikal_shortcode_column_options') ):
    function conikal_shortcode_column_options() {
        $column_options = array(
            'One' => 'one',
            'Two' => 'two',
            'Three' => 'three',
            'Four' => 'four',
            'Five' => 'five'
        );

        return $column_options;
    }
endif;

/*
 * Change show number on block preview
 * */
if( !function_exists('conikal_show_number_block_preview') ) : 
    function conikal_show_number_block_preview($is_preview, $carousel, $column, $show) {
        if ($is_preview && $carousel == 1) {
            switch ($column) {
                case 'two':
                    $show = 2;
                    break;

                case 'three':
                    $show = 3;
                    break;

                case 'four':
                    $show = 4;
                    break;

                case 'five':
                    $show = 5;
                    break;
                
                default:
                    $show = 1;
                    break;
            }
        }

        return $show;
    }
endif;


/*
 * Convert number to world
 * */
if( !function_exists('convert_number_to_words') ) : 
    function convert_number_to_words($number) {
        $hyphen      = '-';
        $conjunction = ' and ';
        $separator   = ', ';
        $negative    = 'negative ';
        $decimal     = ' point ';
        $dictionary  = array(
            0                   => 'zero',
            1                   => 'one',
            2                   => 'two',
            3                   => 'three',
            4                   => 'four',
            5                   => 'five',
            6                   => 'six',
            7                   => 'seven',
            8                   => 'eight',
            9                   => 'nine',
            10                  => 'ten',
            11                  => 'eleven',
            12                  => 'twelve',
            13                  => 'thirteen',
            14                  => 'fourteen',
            15                  => 'fifteen',
            16                  => 'sixteen',
            17                  => 'seventeen',
            18                  => 'eighteen',
            19                  => 'nineteen',
            20                  => 'twenty',
            30                  => 'thirty',
            40                  => 'fourty',
            50                  => 'fifty',
            60                  => 'sixty',
            70                  => 'seventy',
            80                  => 'eighty',
            90                  => 'ninety',
            100                 => 'hundred',
            1000                => 'thousand',
            1000000             => 'million',
            1000000000          => 'billion',
            1000000000000       => 'trillion',
            1000000000000000    => 'quadrillion',
            1000000000000000000 => 'quintillion'
        );

        if (!is_numeric($number)) {
            return false;
        }

        if (($number >= 0 && (int) $number < 0) || (int) $number < 0 - PHP_INT_MAX) {
            // overflow
            trigger_error(
                'convert_number_to_words only accepts numbers between -' . PHP_INT_MAX . ' and ' . PHP_INT_MAX,
                E_USER_WARNING
            );
            return false;
        }

        if ($number < 0) {
            return $negative . convert_number_to_words(abs($number));
        }

        $string = $fraction = null;

        if (strpos($number, '.') !== false) {
            list($number, $fraction) = explode('.', $number);
        }

        switch (true) {
            case $number < 21:
                $string = $dictionary[$number];
                break;
            case $number < 100:
                $tens   = ((int) ($number / 10)) * 10;
                $units  = $number % 10;
                $string = $dictionary[$tens];
                if ($units) {
                    $string .= $hyphen . $dictionary[$units];
                }
                break;
            case $number < 1000:
                $hundreds  = $number / 100;
                $remainder = $number % 100;
                $string = $dictionary[$hundreds] . ' ' . $dictionary[100];
                if ($remainder) {
                    $string .= $conjunction . convert_number_to_words($remainder);
                }
                break;
            default:
                $baseUnit = pow(1000, floor(log($number, 1000)));
                $numBaseUnits = (int) ($number / $baseUnit);
                $remainder = $number % $baseUnit;
                $string = convert_number_to_words($numBaseUnits) . ' ' . $dictionary[$baseUnit];
                if ($remainder) {
                    $string .= $remainder < 100 ? $conjunction : $separator;
                    $string .= convert_number_to_words($remainder);
                }
                break;
        }

        if (null !== $fraction && is_numeric($fraction)) {
            $string .= $decimal;
            $words = array();
            foreach (str_split((string) $fraction) as $number) {
                $words[] = $dictionary[$number];
            }
            $string .= implode(' ', $words);
        }

        return $string;
    }
endif;


/*
 * Get thumbnail size from string to array
 * */
/**
 * @param $id
 * @param $size
 * @return array|false|mixed|string
 */
if( !function_exists('conikal_get_image_by_size') ) : 
    function conikal_get_image_by_size( $id, $size ) {
        global $_wp_additional_image_sizes;

        $sizes = array(
            'thumbnail',
            'thumb',
            'medium',
            'large',
            'full',
        );
        if ( is_string( $size ) && ( ( ! empty( $_wp_additional_image_sizes[ $size ] ) && is_array( $_wp_additional_image_sizes[ $size ] ) ) || in_array( $size, $sizes, true ) ) ) {
            $p_img = wp_get_attachment_image_src( $id, $size );
            return isset($p_img[0]) ? $p_img[0] : '';
        } else {
            if ( is_string( $size ) ) {
                preg_match_all( '/\d+/', $size, $thumb_matches );
                if ( isset( $thumb_matches[0] ) ) {
                    $size = array();
                    $count = count( $thumb_matches[0] );
                    if ( $count > 1 ) {
                        $size[] = $thumb_matches[0][0]; // width
                        $size[] = $thumb_matches[0][1]; // height
                    } elseif ( 1 === $count ) {
                        $size[] = $thumb_matches[0][0]; // width
                        $size[] = $thumb_matches[0][0]; // height
                    } else {
                        $size = false;
                    }
                }
            }
            if ( is_array( $size ) ) {
                // Resize image to custom size
                $p_img = conikal_resize_thumbnail( $id, null, $size[0], $size[1], true );

                return $p_img['url'];
            }
        }

        return '';
    }
endif;


/*
* Resize images dynamically using wp built in functions
* Victor Teixeira
*/
if ( ! function_exists( 'conikal_resize_thumbnail' ) ) : 
	/**
	 * @param int $attach_id
	 * @param string $img_url
	 * @param int $width
	 * @param int $height
	 * @param bool $crop
	 *
	 * @return array
	 * @since 4.2
	 */
	function conikal_resize_thumbnail( $attach_id, $img_url, $width, $height, $crop = false ) {
		// this is an attachment, so we have the ID
		$image_src = array();
		if ( $attach_id ) {
			$image_src = wp_get_attachment_image_src( $attach_id, 'full' );
			$actual_file_path = get_attached_file( $attach_id );
			// this is not an attachment, let's use the image url
		} elseif ( $img_url ) {
			$file_path = wp_parse_url( $img_url );
			$actual_file_path = rtrim( ABSPATH, '/' ) . $file_path['path'];
			$orig_size = getimagesize( $actual_file_path );
			$image_src[0] = $img_url;
			$image_src[1] = $orig_size[0];
			$image_src[2] = $orig_size[1];
		}
		if ( ! empty( $actual_file_path ) ) {
			$file_info = pathinfo( $actual_file_path );
			$extension = '.' . $file_info['extension'];

			// the image path without the extension
			$no_ext_path = $file_info['dirname'] . '/' . $file_info['filename'];

			$cropped_img_path = $no_ext_path . '-' . $width . 'x' . $height . $extension;

			// checking if the file size is larger than the target size
			// if it is smaller or the same size, stop right here and return
			if ( $image_src[1] > $width || $image_src[2] > $height ) {

				// the file is larger, check if the resized version already exists (for $crop = true but will also work for $crop = false if the sizes match)
				if ( file_exists( $cropped_img_path ) ) {
					$cropped_img_url = str_replace( basename( $image_src[0] ), basename( $cropped_img_path ), $image_src[0] );
					$vt_image = array(
						'url' => $cropped_img_url,
						'width' => $width,
						'height' => $height,
					);

					return $vt_image;
				}

				if ( ! $crop ) {
					// calculate the size proportionaly
					$proportional_size = wp_constrain_dimensions( $image_src[1], $image_src[2], $width, $height );
					$resized_img_path = $no_ext_path . '-' . $proportional_size[0] . 'x' . $proportional_size[1] . $extension;

					// checking if the file already exists
					if ( file_exists( $resized_img_path ) ) {
						$resized_img_url = str_replace( basename( $image_src[0] ), basename( $resized_img_path ), $image_src[0] );

						$vt_image = array(
							'url' => $resized_img_url,
							'width' => $proportional_size[0],
							'height' => $proportional_size[1],
						);

						return $vt_image;
					}
				}

				// no cache files - let's finally resize it
				$img_editor = wp_get_image_editor( $actual_file_path );

				if ( is_wp_error( $img_editor ) || is_wp_error( $img_editor->resize( $width, $height, $crop ) ) ) {
					return array(
						'url' => '',
						'width' => '',
						'height' => '',
					);
				}

				$new_img_path = $img_editor->generate_filename();

				if ( is_wp_error( $img_editor->save( $new_img_path ) ) ) {
					return array(
						'url' => '',
						'width' => '',
						'height' => '',
					);
				}
				if ( ! is_string( $new_img_path ) ) {
					return array(
						'url' => '',
						'width' => '',
						'height' => '',
					);
				}

				$new_img_size = getimagesize( $new_img_path );
				$new_img = str_replace( basename( $image_src[0] ), basename( $new_img_path ), $image_src[0] );

				// resized output
				$vt_image = array(
					'url' => $new_img,
					'width' => $new_img_size[0],
					'height' => $new_img_size[1],
				);

				return $vt_image;
			}

			// default output - without resizing
			$vt_image = array(
				'url' => $image_src[0],
				'width' => $image_src[1],
				'height' => $image_src[2],
			);

			return $vt_image;
		}

		return false;
	}
endif;


/**
 *  Remove Google Map API from Gutentor settingt
 *
 * @since Campoal-tapo 2.0.0
 */
if (!function_exists('conikal_gutentor_update_options')) :
    function conikal_gutentor_update_options( $key = '' ) {
        if ( ! empty( $key ) ) {
            delete_option( $key );
            $g_options = get_option( 'gutentor_settings_options' );
            if ( isset( $g_options[ $key ] ) ) {
                // unset( $g_options[ $key ] );
                $g_options[ $key ] = 0;
                update_option( 'gutentor_settings_options', $g_options );
            }
        }
        return false;
    }
endif;


/**
 * Check block and shortcode carousel option
 *
 * @since Campoal-tapo 2.1.0
 */
if (!function_exists('conikal_carousel_mode')) :
    function conikal_carousel_mode( $carousel = 0 ) {
        
        switch ($carousel) {
            case 'no':
                $carousel = 0;
                break;
            
            case 'yes':
                $carousel = 1;
                break;

            default:
                $carousel = $carousel;
                break;
        }

        return $carousel;
    }
endif;


/**
 * Disable admin bar for everyone but administrators
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_disable_admin_bar')):

    // css override for the admin page
    function conikal_remove_admin_bar_style_backend() { 
        echo '<style type="text/css" media="screen">body.admin-bar #wpcontent, body.admin-bar #adminmenu { padding-top: 0px !important; }</style>';
    } 

    // css override for the frontend
    function conikal_remove_admin_bar_style_frontend() {
        echo '<style type="text/css" media="screen">
        html { margin-top: 0px !important; }
        * html body { margin-top: 0px !important; }
        </style>';
    }

    function conikal_disable_admin_bar() {
        
        if (!current_user_can('manage_options')) {
        
            // for the admin page
            remove_action('admin_footer', 'wp_admin_bar_render', 1000);

            // for the front-end
            remove_action('wp_footer', 'wp_admin_bar_render', 1000);

            add_filter('admin_head', 'conikal_remove_admin_bar_style_backend', 10);
            add_filter('wp_head', 'conikal_remove_admin_bar_style_frontend', 10);
        } else {
            function conikal_add_admin_bar_style_frontend() {
                global $campoal_options;
                $top_menu                   = isset($campoal_options['conikal_top_menu_field']) && !wp_is_mobile() ? $campoal_options['conikal_top_menu_field'] : 0;
                $type_menu                  = isset($campoal_options['conikal_type_header_menu_field']) ? $campoal_options['conikal_type_header_menu_field'] : 'none';

                if (is_admin_bar_showing() && !wp_is_mobile()) {
                    if ($top_menu == 1 && $type_menu != 'none') {
                        echo '<style type="text/css" media="screen">.top-menu, .header-menu, .search-menu {top: 32px !important}</style>';
                    } else {
                        echo '<style type="text/css" media="screen">.header-menu, .search-menu {top: 32px !important}</style>';
                    }
                } else if (is_admin_bar_showing() && wp_is_mobile()) {
                    if ($top_menu == 1 && $type_menu != 'none') {
                        echo '<style type="text/css" media="screen">.top-menu, .header-menu, .search-menu {top: 46px !important}</style>';
                    } else {
                        echo '<style type="text/css" media="screen">.header-menu, .search-menu {top: 46px !important}</style>';
                    }
                }
            }
            add_filter('wp_head', 'conikal_add_admin_bar_style_frontend', 10);
        }
    }
endif;
add_action('init', 'conikal_disable_admin_bar');


/**
 * Add custom css when unlicensed
 *
 * @since Campoal 2.1.1
 */
if( !function_exists('conikal_license_key_style') ): 
    function conikal_license_key_style() {
        if (is_admin() && substr($_SERVER['REMOTE_ADDR'], 0, 4) != '127.' && $_SERVER['REMOTE_ADDR'] != '::1') {
            $license    = ConikalLicense();
            $valid_status   = $license->validate_status();

            if (!array_key_exists('is_valid', $valid_status) || $valid_status['is_valid'] != 1 || empty($valid_status['github_token'])) {
                $style = '
                    #wpadminbar ul#wp-admin-bar-root-default>li#wp-admin-bar-campoal_options .ab-sub-wrapper, 
                    .toplevel_page_campoal_options .wp-submenu, 
                    .redux-sidebar .redux-group-menu li {
                        display: none; }
                    .redux-sidebar .redux-group-menu > li:first-child {
                        display: block; }
                ';
            } else {
                $style = '
                    .redux-sidebar .redux-group-menu > li:first-child {
                        display: none; }
                ';
            }
            return $style;
        } else {
            return false;
        }
    }
endif;

/**
* Remove init HTML tags for embed code
*
* @since Campoal 2.3.2
*/
if( !function_exists('conikal_remove_init_html_tags') ):
	function conikal_remove_init_html_tags($origin_html) {
		if (empty($origin_html)) {
			return false;
		}

		$findHTML = array(
			'<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" "http://www.w3.org/TR/REC-html40/loose.dtd">',
			'<html><body>',
			'</body></html>',
            '×',
            '✕',		);
		$changeHTML = array('', '', '', 'x', 'x');

		$inline_style = str_replace($findHTML, $changeHTML, $origin_html);

		return $inline_style;
	}
endif;
?>