<?php
/**
 * @package WordPress
 * @subpackage Campoal
 */


/**
 * Get petitinos for gutenberg block
 *
 * @since Campoal 2.2.0
 */

if( !function_exists('conikal_petitions_to_block') ): 
    function conikal_petitions_to_block($attributes, $is_preview, $country_selected = false) {

        extract(shortcode_atts(array(
            'title'     		=> '',
            'type'				=> 'recent',
            'show'      		=> '4',
            'categories' 		=> '',
            'topics' 			=> '',
            'style'     		=> 'grid',
            'carousel'  		=> 'no',
            'column'    		=> 'four',
            'hover'     		=> false,
            'order'     		=> 'DESC',
            'orderby'   		=> 'date',
            'petition_ids' 		=> '',
        ), $attributes));

        $show = conikal_show_number_block_preview($is_preview, $carousel, $column, $show);

        global $campoal_options;
        global $current_user;

        $minimum_signature 		= isset($campoal_options['conikal_minimum_signature_field']) ? $campoal_options['conikal_minimum_signature_field'] : 0;
        $country_selection_mode = isset($campoal_options['conikal_country_selection_mode_field']) ? $campoal_options['conikal_country_selection_mode_field'] : 0;
        $filter_by_country 		= isset($campoal_options['conikal_filter_by_country_field']) ? $campoal_options['conikal_filter_by_country_field'] : 0;
                
        // if no country select param will use user selection instead
        if (empty($country_selected)) {
            $country_selected       = conikal_get_country_selected($current_user);
        }

        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        
        $args = array(
            'post_type'        => 'petition',
            'posts_per_page'   => $show,
            'paged'            => $paged,
            'order'            => $order,
            'orderby'          => conikal_meta_key_ordering_filter($orderby),
            'post_status'      => 'publish' );

        if ( $type == 'by_id' && !empty($petition_ids) ) {
            $petition_ids = array_map('intval', explode(',', $petition_ids));
            $args['post__in'] = $petition_ids;
        }

        // add meta key or supporters ordering
        if ($orderby == 'supporters') {
            $args['meta_key'] = 'petition_sign';
        }

        if ($orderby == 'views') {
            $args['meta_key'] = 'post_views_count';
        }

        $args['tax_query'] = array('relation' => 'OR');
        if (!empty($categories)) {
            array_push($args['tax_query'], array(
                'taxonomy' => 'petition_category',
                'terms'    => $categories,
            ));
        }

        if (!empty($topics)) {
            array_push($args['tax_query'], array(
                'taxonomy' => 'petition_topics',
                'terms'    => $topics,
            ));
        }

        $args['meta_query'] = array('relation' => 'AND');

        if ($minimum_signature != 0) {
            array_push($args['meta_query'], array(
                'key'     => 'petition_sign',
                'value'   => $minimum_signature,
                'type'    => 'NUMERIC',
                'compare' => '>='
            ));
        }

        // only show petition matched with country selected
        if ($country_selection_mode && $filter_by_country && $country_selected != 'WORLD') {
            array_push($args['meta_query'], array(
                'key'     => 'petition_country',
                'value'   => $country_selected,
                'compare' => 'IN'
            ));
        }
            
        if ($type == 'victory') {
            array_push($args['meta_query'], array(
                'key'     => 'petition_status',
                'value'   => '1',
                'compare' => '=='
            ));
        } else if ($type == 'featured') {
            array_push($args['meta_query'], array(
                'key'     => 'petition_featured',
                'value'   => '1',
                'compare' => '=='
            ));
        } else if ($type == 'victory_featured') {
            array_push($args['meta_query'], array(
                'key'     => 'petition_victory',
                'value'   => '1',
                'compare' => '=='
            ));
        } else if ($type == 'recent') {
            array_push($args['meta_query'], array(
                'key'     => 'petition_status',
                'value'   => '2',
                'compare' => '!='
            ));
        }

        $posts = new WP_Query($args);

        wp_reset_postdata();
        wp_reset_query();

        return $posts;
    }
endif;