<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Social button widget
 *
 * @since Campoal Tapo 1.0.0
 */
class Social_Widget extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'social_sidebar', 'description' => 'Social networks links.');
        $control_ops = array('id_base' => 'social_widget');
        parent::__construct('social_widget', 'Campoal Social Networks', $widget_ops, $control_ops);
    }

    function form($instance) {
        $defaults = array(
            'title' => '',
            'style' => 'color',
            'facebook' => '',
            'twitter' => '',
            'google' => '',
            'linkedin' => '',
            'instagram' => '',
            'youtube' => '',
            'medium' => '',
            'pinterest' => '',
            'tumblr' => '',
            'vimeo' => '',
            'flickr' => '',
            'vk' => '',
            'weibo' => '',
        );

        $theme_arr = array(
            'color' => esc_html__('Color', 'campoal-tapo'),
            'light' => esc_html__('Light', 'campoal-tapo'),
            'dark' => esc_html__('Dark', 'campoal-tapo'),
        );
        $instance = wp_parse_args((array) $instance, $defaults); ?>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('title')) ?>"><?php esc_html_e('Title', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')) ?>" name="<?php echo esc_attr($this->get_field_name('title')) ?>" value="<?php echo esc_attr($instance['title']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('style')) ?>"><?php esc_html_e('Theme', 'campoal-tapo') ?>:</label>
                <select class="widefat" id="<?php echo esc_attr($this->get_field_id('style')) ?>" name="<?php echo esc_attr($this->get_field_name('style')) ?>">
                    <?php foreach ($theme_arr as $key => $name) { ?>
                        <option value="<?php echo esc_attr($key) ?>" <?php echo esc_attr($instance['style'] == $key ? 'selected' : '') ?>><?php echo esc_html($name) ?></option>
                    <?php } ?>
                </select>
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('facebook')) ?>"><?php esc_html_e('Facebook Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('facebook')) ?>" name="<?php echo esc_attr($this->get_field_name('facebook')) ?>" value="<?php echo esc_attr($instance['facebook']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('twitter')) ?>"><?php esc_html_e('Twitter Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('twitter')) ?>" name="<?php echo esc_attr($this->get_field_name('twitter')) ?>" value="<?php echo esc_attr($instance['twitter']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('google')) ?>"><?php esc_html_e('Google+ Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('google')) ?>" name="<?php echo esc_attr($this->get_field_name('google')) ?>" value="<?php echo esc_attr($instance['google']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('linkedin')) ?>"><?php esc_html_e('LinkedIn Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('linkedin')) ?>" name="<?php echo esc_attr($this->get_field_name('linkedin')) ?>" value="<?php echo esc_attr($instance['linkedin']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('instagram')) ?>"><?php esc_html_e('Instagram Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('instagram')) ?>" name="<?php echo esc_attr($this->get_field_name('instagram')) ?>" value="<?php echo esc_attr($instance['instagram']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('youtube')) ?>"><?php esc_html_e('Youtube Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('youtube')) ?>" name="<?php echo esc_attr($this->get_field_name('youtube')) ?>" value="<?php echo esc_attr($instance['youtube']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('medium')) ?>"><?php esc_html_e('Medium Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('medium')) ?>" name="<?php echo esc_attr($this->get_field_name('medium')) ?>" value="<?php echo esc_attr($instance['medium']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('pinterest')) ?>"><?php esc_html_e('Pinterest Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('pinterest')) ?>" name="<?php echo esc_attr($this->get_field_name('pinterest')) ?>" value="<?php echo esc_attr($instance['pinterest']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('tumblr')) ?>"><?php esc_html_e('Tumblr Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('tumblr')) ?>" name="<?php echo esc_attr($this->get_field_name('tumblr')) ?>" value="<?php echo esc_attr($instance['tumblr']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('vimeo')) ?>"><?php esc_html_e('Vimeo Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('vimeo')) ?>" name="<?php echo esc_attr($this->get_field_name('vimeo')) ?>" value="<?php echo esc_attr($instance['vimeo']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('flickr')) ?>"><?php esc_html_e('Flickr Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('flickr')) ?>" name="<?php echo esc_attr($this->get_field_name('flickr')) ?>" value="<?php echo esc_attr($instance['flickr']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('vk')) ?>"><?php esc_html_e('Vk Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('vk')) ?>" name="<?php echo esc_attr($this->get_field_name('vk')) ?>" value="<?php echo esc_attr($instance['vk']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('weibo')) ?>"><?php esc_html_e('Weibo Link', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('weibo')) ?>" name="<?php echo esc_attr($this->get_field_name('weibo')) ?>" value="<?php echo esc_attr($instance['weibo']) ?>" />
            </p>
    <?php }


    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = sanitize_text_field($new_instance['title']);
        $instance['style'] = sanitize_text_field($new_instance['style']);
        $instance['facebook'] = sanitize_text_field($new_instance['facebook']);
        $instance['twitter'] = sanitize_text_field($new_instance['twitter']);
        $instance['google'] = sanitize_text_field($new_instance['google']);
        $instance['linkedin'] = sanitize_text_field($new_instance['linkedin']);
        $instance['instagram'] = sanitize_text_field($new_instance['instagram']);
        $instance['youtube'] = sanitize_text_field($new_instance['youtube']);
        $instance['medium'] = sanitize_text_field($new_instance['medium']);
        $instance['pinterest'] = sanitize_text_field($new_instance['pinterest']);
        $instance['tumblr'] = sanitize_text_field($new_instance['tumblr']);
        $instance['vimeo'] = sanitize_text_field($new_instance['vimeo']);
        $instance['flickr'] = sanitize_text_field($new_instance['flickr']);
        $instance['vk'] = sanitize_text_field($new_instance['vk']);
        $instance['weibo'] = sanitize_text_field($new_instance['weibo']);

        if(function_exists('icl_register_string')) {
            icl_register_string('conikal_social_widget', 'social_widget_title', sanitize_text_field($new_instance['title']));
            icl_register_string('conikal_social_widget', 'social_widget_style', sanitize_text_field($new_instance['style']));
            icl_register_string('conikal_social_widget', 'social_widget_facebook', sanitize_text_field($new_instance['facebook']));
            icl_register_string('conikal_social_widget', 'social_widget_twitter', sanitize_text_field($new_instance['twitter']));
            icl_register_string('conikal_social_widget', 'social_widget_google', sanitize_text_field($new_instance['google']));
            icl_register_string('conikal_social_widget', 'social_widget_linkedin', sanitize_text_field($new_instance['linkedin']));
            icl_register_string('conikal_social_widget', 'social_widget_instagram', sanitize_text_field($new_instance['instagram']));
            icl_register_string('conikal_social_widget', 'social_widget_youtube', sanitize_text_field($new_instance['youtube']));
            icl_register_string('conikal_social_widget', 'social_widget_medium', sanitize_text_field($new_instance['medium']));
            icl_register_string('conikal_social_widget', 'social_widget_pinterest', sanitize_text_field($new_instance['pinterest']));
            icl_register_string('conikal_social_widget', 'social_widget_tumblr', sanitize_text_field($new_instance['tumblr']));
            icl_register_string('conikal_social_widget', 'social_widget_vimeo', sanitize_text_field($new_instance['vimeo']));
            icl_register_string('conikal_social_widget', 'social_widget_flickr', sanitize_text_field($new_instance['flickr']));
            icl_register_string('conikal_social_widget', 'social_widget_vk', sanitize_text_field($new_instance['vk']));
            icl_register_string('conikal_social_widget', 'social_widget_weibo', sanitize_text_field($new_instance['weibo']));
        }

        return $instance;
    }

    function widget($args, $instance) {
        extract($args);
        global $campoal_options;
        $external_link = isset($campoal_options['conikal_external_link_field']) ? $campoal_options['conikal_external_link_field'] : 0;

        $title = apply_filters('widget_title', $instance['title']);

        echo wp_kses_post($before_widget);
        if ($title) {
            echo wp_kses_post($before_title) . esc_html($title) . wp_kses_post($after_title);
        }

        // set class theme
        switch ($instance['style']) {
            case 'color':
                $theme_class = '';
                break;

            case 'light':
                $theme_class = 'inverted';
                break;

            case 'dark':
                $theme_class = 'basic';
                break;
            
            default:
                $theme_class = '';
                break;
        } ?>
        <div class="widget-social-buttons">

        <?php if (array_key_exists('facebook', $instance) && $instance['facebook']) {
            if (function_exists('icl_t')) {
                $social_facebook = icl_t('conikal_social_widget', 'social_widget_facebook', $instance['facebook']);
            } else {
                $social_facebook = $instance['facebook'];
            } ?>
            <a href="<?php echo esc_url($social_facebook) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'facebook') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="facebook f icon"></i></a>
        <?php }
        if (array_key_exists('twitter', $instance) && $instance['twitter']) {
            if (function_exists('icl_t')) {
                $social_twitter = icl_t('conikal_social_widget', 'social_widget_twitter', $instance['twitter']);
            } else {
                $social_twitter = $instance['twitter'];
            } ?>
            <a href="<?php echo esc_url($social_twitter) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'twitter') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="twitter icon"></i></a>
        <?php }
        if (array_key_exists('google', $instance) && $instance['google']) {
            if (function_exists('icl_t')) {
                $social_google = icl_t('conikal_social_widget', 'social_widget_google', $instance['google']);
            } else {
                $social_google = $instance['google'];
            } ?>
            <a href="<?php echo esc_url($social_google) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'google plus') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="google plus g icon"></i></a>
        <?php }
        if (array_key_exists('linkedin', $instance) && $instance['linkedin']) {
            if (function_exists('icl_t')) {
                $social_linkedin = icl_t('conikal_social_widget', 'social_widget_linkedin', $instance['linkedin']);
            } else {
                $social_linkedin = $instance['linkedin'];
            } ?>
            <a href="<?php echo esc_url($social_linkedin) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'linkedin') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="linkedin icon"></i></a>
        <?php }
        if (array_key_exists('instagram', $instance) && $instance['instagram']) {
            if (function_exists('icl_t')) {
                $social_instagram = icl_t('conikal_social_widget', 'social_widget_instagram', $instance['instagram']);
            } else {
                $social_instagram = $instance['instagram'];
            } ?>
            <a href="<?php echo esc_url($social_instagram) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'instagram') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="instagram icon"></i></a>
        <?php }
        if (array_key_exists('youtube', $instance) && $instance['youtube']) {
            if (function_exists('icl_t')) {
                $social_youtube = icl_t('conikal_social_widget', 'social_widget_youtube', $instance['youtube']);
            } else {
                $social_youtube = $instance['youtube'];
            } ?>
            <a href="<?php echo esc_url($social_youtube) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'youtube') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="youtube icon"></i></a>
        <?php }
        if (array_key_exists('medium', $instance) && $instance['medium']) {
            if (function_exists('icl_t')) {
                $social_medium = icl_t('conikal_social_widget', 'social_widget_medium', $instance['medium']);
            } else {
                $social_medium = $instance['medium'];
            } ?>
            <a href="<?php echo esc_url($social_medium) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'black') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="medium m icon"></i></a>
        <?php }
        if (array_key_exists('pinterest', $instance) && $instance['pinterest']) {
            if (function_exists('icl_t')) {
                $social_pinterest = icl_t('conikal_social_widget', 'social_widget_pinterest', $instance['pinterest']);
            } else {
                $social_pinterest = $instance['pinterest'];
            } ?>
            <a href="<?php echo esc_url($social_pinterest) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'pinterest') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="pinterest icon"></i></a>
        <?php }
        if (array_key_exists('tumblr', $instance) && $instance['tumblr']) {
            if (function_exists('icl_t')) {
                $social_tumblr = icl_t('conikal_social_widget', 'social_widget_tumblr', $instance['tumblr']);
            } else {
                $social_tumblr = $instance['tumblr'];
            } ?>
            <a href="<?php echo esc_url($social_tumblr) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'tumblr') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="tumblr icon"></i></a>
        <?php }
        if (array_key_exists('vimeo', $instance) && $instance['vimeo']) {
            if (function_exists('icl_t')) {
                $social_vimeo = icl_t('conikal_social_widget', 'social_widget_vimeo', $instance['vimeo']);
            } else {
                $social_vimeo = $instance['vimeo'];
            } ?>
            <a href="<?php echo esc_url($social_vimeo) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'vimeo') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="vimeo icon"></i></a>
        <?php }
        if (array_key_exists('vk', $instance) && $instance['vk']) {
            if (function_exists('icl_t')) {
                $social_vk = icl_t('conikal_social_widget', 'social_widget_vk', $instance['vk']);
            } else {
                $social_vk = $instance['vk'];
            } ?>
            <a href="<?php echo esc_url($social_vk) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'vk') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="vk icon"></i></a>
        <?php }
        if (array_key_exists('weibo', $instance) && $instance['weibo']) {
            if (function_exists('icl_t')) {
                $social_weibo = icl_t('conikal_social_widget', 'social_widget_weibo', $instance['weibo']);
            } else {
                $social_weibo = $instance['weibo'];
            } ?>
            <a href="<?php echo esc_url($social_weibo) ?>" class="ui icon <?php echo esc_attr($instance['style'] != 'color' ? $theme_class : 'weibo') ?> button" target="<?php echo esc_attr($external_link != 0 ? '_blank' : '_self') ?>"><i class="weibo icon"></i></a>
        <?php } ?>
        
        </div>
        <?php 
        echo wp_kses_post($after_widget);
    }
} ?>