<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Topics card widget
 *
 * @since Campoal Tapo 1.0.0
 */
class Topic_Cards_Widget extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'topic_cards_sidebar', 'description' => 'Topic Cards.');
        $control_ops = array('id_base' => 'topic_cards_widget');
        parent::__construct('topic_cards_widget', 'Campoal Topic Cards', $widget_ops, $control_ops);
    }

    function form($instance) {
        $defaults = array(
            'title' => '',
            'topics' => '',
            'orderby' => 'count',
            'order' => 'random',
            'limit' => '3',
        );
        $instance = wp_parse_args((array) $instance, $defaults);
        $orderby_array = array('id' => esc_html__('ID', 'campoal-tapo'), 'count' => esc_html__('Count', 'campoal-tapo'), 'name' => esc_html__('Name', 'campoal-tapo'));
        $order_array = array('DESC' => esc_html__('Descending', 'campoal-tapo'), 'ASC' => esc_html__('Ascending', 'campoal-tapo'), 'random' => esc_html__('Random', 'campoal-tapo')); ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')) ?>"><?php esc_html_e('Title', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')) ?>" name="<?php echo esc_attr($this->get_field_name('title')) ?>" value="<?php echo esc_attr($instance['title']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('topics')) ?>"><?php esc_html_e('Topics (id or slug, separate by commas)', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('topics')) ?>" name="<?php echo esc_attr($this->get_field_name('topics')) ?>" value="<?php echo esc_attr($instance['topics']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('orderby')) ?>'"><?php esc_html_e('Order by', 'campoal-tapo') ?>:</label>
            <select type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('orderby')) ?>" name="<?php echo esc_attr($this->get_field_name('orderby')) ?>">
        <?php foreach ($orderby_array as $value => $name) { ?>
                <option value="<?php echo esc_attr($value) ?>"<?php echo esc_attr($instance['orderby'] === $value ? ' selected="selected"' : '') ?>><?php echo esc_html($name) ?></option>
        <?php } ?>            
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('order')) ?>"><?php esc_html_e('Order', 'campoal-tapo') ?>:</label>
            <select type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('order')) ?>" name="<?php echo esc_attr($this->get_field_name('order')) ?>">

        <?php foreach ($order_array as $value => $name) { ?>
            <option value="<?php echo esc_attr($value) ?>" <?php echo esc_attr($instance['order'] === $value ? ' selected="selected"' : '') ?>><?php echo esc_html($name) ?></option>
        <?php } ?>            
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('limit')) ?>"><?php esc_html_e('Number of cards to show', 'campoal-tapo') ?>:</label>
            <input type="text" size="3" id="<?php echo esc_attr($this->get_field_id('limit')) ?>" name="<?php echo esc_attr($this->get_field_name('limit')) ?>" value="<?php echo esc_attr($instance['limit']) ?>" />
        </p>
    <?php } 


    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = sanitize_text_field($new_instance['title']);
        $instance['topics'] = sanitize_text_field($new_instance['topics']);
        $instance['orderby'] = sanitize_text_field($new_instance['orderby']);
        $instance['order'] = sanitize_text_field($new_instance['order']);
        $instance['limit'] = sanitize_text_field($new_instance['limit']);

        if (function_exists('icl_register_string')) {
            icl_register_string('conikal_topic_cards_widget', 'topic_cards_widget_title', sanitize_text_field($new_instance['title']));
            icl_register_string('conikal_topic_cards_widget', 'topic_cards_widget_title', sanitize_text_field($new_instance['topics']));
            icl_register_string('conikal_topic_cards_widget', 'topic_cards_widget_orderby', sanitize_text_field($new_instance['orderby']));
            icl_register_string('conikal_topic_cards_widget', 'topic_cards_widget_order', sanitize_text_field($new_instance['order']));
            icl_register_string('conikal_topic_cards_widget', 'topic_cards_widget_limit', sanitize_text_field($new_instance['limit']));
        }

        return $instance;
    }

    function widget($args, $instance) {
        global $campoal_options;
        
        $minimum_signature = isset($campoal_options['conikal_minimum_signature_field']) ? $campoal_options['conikal_minimum_signature_field'] : 0;
        extract($args);
        $title = apply_filters('widget_title', $instance['title']);
        $slugs = $instance['topics'];
        $orderby = $instance['orderby'];
        $order = $instance['order'];

        // get follow topics
        $current_user = wp_get_current_user();
        $follow_topics = get_user_meta($current_user->ID, 'follow_topics', true);

        echo wp_kses_post($before_widget);
        if ($title) {
            echo wp_kses_post($before_title) . esc_html($title) . wp_kses_post($after_title);
        }

        if ($instance['limit'] && $instance['limit'] != '') {
            $limit = $instance['limit'];
        } else {
            $limit = 4;
        }

        if ($slugs != '') {
            $slugs = str_replace(' ', '', $slugs);
            $slugs = explode(',', $slugs);
        } else {
            $slugs = array();
            $terms = get_terms( 
                array(
                    'taxonomy' => 'petition_topics',
                    'orderby' => $orderby,
                    'order' => ($order != 'random' ? $order : 'DESC'),
                    'hide_empty' => true,
                    'number' => $limit,
                ) 
            );

            if (!is_wp_error($terms)) {
                foreach ($terms as $term ) {
                    array_push($slugs, $term->slug);
                }
            }
        }

        $taxonomy_name = 'petition_topics';
        $term_meta_image = 'petition_topics_image';
        ?>

        <?php if ($slugs) : ?>
        <div class="topic-cards">
            <?php for ($i=0; $i < $limit; $i++) {
                // get term
                if (array_key_exists($i, $slugs)) {
                    $id_slug = intval($slugs[$i]);
                    $term = get_term_by('id', $id_slug, $taxonomy_name);
                    if (!$term) {
                        $id_slug = strval($slugs[$i]);
                        $term = get_term_by('slug', $id_slug, $taxonomy_name);
                    }
                }
                
                if ($term) {
                    // get post
                    $args = array( 
                        'posts_per_page' => 1,
                        'paged' => 1,
                        'post_type' => 'petition',
                        'post_status' => 'publish'
                    );

                    $args['tax_query'] = array(
                        'relation' => 'OR',
                        array(
                            'taxonomy' => 'petition_topics',
                            'terms'    => $term->term_id,
                        )
                    );
                    $args['tag_id'] = $term->term_id;
                    $args['meta_query'] = array('relation' => 'AND');

                    if ($minimum_signature != 0) {
                        array_push(
                            $args['meta_query'], array(
                                'key'     => 'petition_sign',
                                'value'   => $minimum_signature,
                                'type'    => 'NUMERIC',
                                'compare' => '>='
                            )
                        );
                    }
                    $postslist = new WP_Query($args);
                    
                    if ($postslist->have_posts() ) {
                        $post = $postslist->posts[0];
                    }


                    $term_image = get_term_meta($term->term_id, $term_meta_image, true);
                    if ($term_image == '' && $postslist->have_posts() ) {
                        $term_image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'conikal-petition-medium');
                        if ($term_image) {
                            $term_image = $term_image[0];
                        } else {
                            $term_image = get_template_directory_uri().'/images/cover-card.svg';
                        }
                    } else {
                        $term_image = get_template_directory_uri().'/images/cover-card.svg';
                    }

                    $term_link  = get_term_link($term->term_id, $taxonomy_name); ?>
                    <div class="topic-card snip">
                    <img src="<?php echo esc_url($term_image ? esc_url($term_image) : '') ?>" alt="<?php echo esc_attr($term->name) ?>"/>
                    <a href="<?php echo esc_url($term_link) ?>" class="caption" data-bjax><h3><?php echo esc_html($term->name) ?></h3></a>

                    <?php if (is_user_logged_in()) {
                        if ($follow_topics != '') {
                            if (in_array($term->term_id, $follow_topics) === false) { ?>
                                <button id="follow-topic-<?php echo esc_attr($term->term_id) ?>" class="follow-topic follow" data-id="<?php echo esc_attr($term->term_id) ?>"><?php esc_html_e('Follow', 'campoal-tapo') ?></button>
                            <?php } else { ?>
                                <button id="follow-topic-<?php echo esc_attr($term->term_id) ?>" class="follow-topic following" data-id="<?php echo esc_attr($term->term_id) ?>"><?php esc_html_e('Following', 'campoal-tapo') ?></button>
                            <?php } ?>
                        <?php } else { ?>
                                <button id="follow-topic-<?php echo esc_attr($term->term_id) ?>" class="follow-topic follow" data-id="<?php echo esc_attr($term->term_id) ?>"><?php esc_html_e('Follow', 'campoal-tapo') ?></button>
                        <?php } ?>
                    <?php } else { ?>
                            <button class="signin-btn follow-topic follow"><?php esc_html_e('Follow', 'campoal-tapo') ?></button>
                    <?php } ?>
                    </div>
                <?php }
                }
            wp_nonce_field('follow_ajax_nonce', 'securityFollow', true); ?>
        </div>
    <?php endif; ?>

        <?php 
        echo wp_kses_post($after_widget);
        wp_reset_postdata();
        wp_reset_query();
    }
} ?>