(function($) {
    "use strict";

    place_autocomplete('petition');
    place_autocomplete('_give_');
    place_autocomplete('user');
    function place_autocomplete(id) {
        var stateOptions = {
            strictBounds: false,
            types: [main_vars.google_place_types],
            language: [main_vars.site_locale]
        }
        if ($('#' + id + '_address').length > 0) {
            var address = document.getElementById(id + '_address');
            var addressAuto = new google.maps.places.Autocomplete(address, stateOptions);
            google.maps.event.addListener(addressAuto, 'place_changed', function() {
                var place = addressAuto.getPlace();
                $('#' + id + '_address').blur();
                //setTimeout(function() { $('#new_address').val(place.name); }, 1);
                var lat = place.geometry.location.lat,
                    lng = place.geometry.location.lng;

                for (var i = 0; i < place.address_components.length; i++) {
                    var addressType = place.address_components[i].types[0];

                    var val = place.address_components[i].short_name;

                    if (addressType === 'administrative_area_level_1') {
                        $('#' + id + '_state').val(val);
                    } else if (addressType === 'administrative_area_level_2') {
                        $('#' + id + '_city').val(val);
                    } else if (addressType === 'locality') {
                        $('#' + id + '_city').val(val);
                    } else if (addressType === 'sublocality') {
                        $('#' + id + '_neighborhood').val(val);
                    } else if (addressType === 'neighborhood') {
                        $('#' + id + '_neighborhood').val(val);
                    } else if (addressType === 'sublocality_level_1') {
                        $('#' + id + '_neighborhood').val(val);
                    } else if (addressType === 'country') {
                        $('#' + id + '_country').val(val);
                    } else if (addressType === 'postal_code') {
                        $('#' + id + '_zip').val(val);
                    }

                }
                $('#' + id + '_lat').val(lat);
                $('#' + id + '_lng').val(lng);
                return false;
            });
        }
        $('#' + id + '_address').keydown(function(){
            if ($(this).val().length <= 1) {
                $('#' + id + '_country').val('');
                $('#' + id + '_state').val('');
                $('#' + id + '_city').val('');
                $('#' + id + '_neighborhood').val('');
                $('#' + id + '_zip').val('');
                $('#' + id + '_lat').val('');
                $('#' + id + '_lng').val('');
            }
        });
    }

    function parseVideoURL(url, id_prefix) {

        function getParm(url, base) {
            var re = new RegExp("(\\?|&)" + base + "\\=([^&]*)(&|$)");
            var matches = url.match(re);
            if (matches) {
                return (matches[2]);
            } else {
                return ("");
            }
        }

        var retVal = {};
        var matches;
        var success = false;

        if (url.match('http(s)?://(www.)?youtube|youtu\.be')) {
            if (url.match('embed')) {
                retVal.id = url.split(/embed\//)[1].split('"')[0];
            } else {
                retVal.id = url.split(/v\/|v=|youtu\.be\//)[1].split(/[?&]/)[0];
            }
            retVal.provider = "youtube";
            retVal.url = 'https://www.youtube.com/embed/' + retVal.id;
            retVal.link = 'https://www.youtube.com/watch?v=' + retVal.id;
            retVal.thumb = 'https://img.youtube.com/vi/' + retVal.id + '/maxresdefault.jpg';
            retVal.thumb_small = 'https://img.youtube.com/vi/' + retVal.id + '/hqdefault.jpg';
            retVal.settings = {
                color: 'white',
                theme: 'light',
                controls: 1,
                rel: 0,
                modestbranding: 1,
                showinfo: 0,
                modestbranding: 1
            };
            success = true;
        } else if (matches = url.match(/^.*(vimeo\.com\/)((channels\/[A-z]+\/)|(groups\/[A-z]+\/videos\/))?([0-9]+)/)) {
            retVal.provider = "vimeo";
            retVal.id = matches[5];
            retVal.url = 'http://player.vimeo.com/video/' + retVal.id;
            retVal.link = 'https://vimeo.com/' + retVal.id;
            $.ajax({
                type:'GET',
                url: 'http://vimeo.com/api/v2/video/' + retVal.id + '.json',
                jsonp: 'callback',
                dataType: 'jsonp',
                success: function(data){
                    retVal.thumb = data[0].thumbnail_large;
                    retVal.thumb_small = data[0].thumbnail_medium;
                    $(id_prefix + 'thumb').val(retVal.thumb);
                    $(id_prefix + 'thumb_small').val(retVal.thumb_small);
                    console.log(data)
                }
            });
            retVal.settings = {
                color: 'ffffff',
                badge: 0,
                byline: 0,
                portrait: 0,
                title: 0
            };
            success = true;
        } else {
            retVal.url = url;
            success = true;
        }

        if (success) {
            return retVal;
        } else {
            alert('No valid media id detected');
        }
    }

    // Add petition category and topics image button
    if ($('#topicsImageBtn').length > 0) {
        if ( typeof wp !== 'undefined' && wp.media && wp.media.editor) {
            $(document).on('click', '#topicsImageBtn', function(e) {
                e.preventDefault();
                var button = $(this);
                var id = button.prev();
                wp.media.editor.send.attachment = function(props, attachment) {
                    id.val(attachment.url);
                };
                wp.media.editor.open(button);
                return false;
            });
        }
    }

    if ($('#categoryImageBtn').length > 0) {
        if ( typeof wp !== 'undefined' && wp.media && wp.media.editor) {
            $(document).on('click', '#categoryImageBtn', function(e) {
                e.preventDefault();
                var button = $(this);
                var id = button.prev();
                wp.media.editor.send.attachment = function(props, attachment) {
                    id.val(attachment.url);
                };
                wp.media.editor.open(button);
                return false;
            });
        }
    }

    // Petition video thumbnail
    videoThumbnailUrl('#petition_');
    videoThumbnailUrl('#_give_');
    videoThumbnailUrl('#update_');
    videoThumbnailUrl('#citation_');

    function videoThumbnailUrl(id_prefix) {
       $(id_prefix + 'video').on('focusout', function() {
            var video_url = $(id_prefix + 'video').val(),
                video = parseVideoURL(video_url, id_prefix);
            $(id_prefix + 'video').val(video.link)
            $(id_prefix + 'thumb').val(video.thumb)
            $(id_prefix + 'thumb_small').val(video.thumb_small);
        }); 
    }


    // License admin notice dismiss
    $(
        function () {
            $( '.conikal-license-notice .notice-dismiss' ).click(
                function (event) {
                    event.preventDefault();
                    var $this = $( this );

                    var attr_value, option_name, dismissible_length, data;

                    attr_value = $this.parent().attr( 'data-dismissible' ).split( '-' );

                    // remove the dismissible length from the attribute value and rejoin the array.
                    dismissible_length = attr_value.pop();

                    option_name = attr_value.join( '-' );

                    data = {
                        'action': 'conikal_dismiss_admin_notice',
                        'option_name': option_name,
                        'dismissible_length': dismissible_length,
                        // 'nonce': dismissible_notice.nonce
                    };

                    // We can also pass the url value separately from ajaxurl for front end AJAX implementations
                    $.post( ajaxurl, data );
                }
            );
        }
    )

})(jQuery);