<?php

/**
 * Popular petitions shortcode
 */
if( !function_exists('conikal_popular_petitions_shortcode') ): 
    function conikal_popular_petitions_shortcode($attrs, $content = null) {
        extract(shortcode_atts(array(
            'title'     => 'Popular petitions',
            'show'      => '4',
            'category'  => '',
            'style'     => 'grid',
            'carousel'  => 'no',
            'column'    => 'four',
            'hover'     => false,
        ), $attrs));

        global $campoal_options;
        $minimum_signature = isset($campoal_options['conikal_minimum_signature_field']) ? $campoal_options['conikal_minimum_signature_field'] : 0;

        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

        $args = array(
            'posts_per_page'   => $show,
            'paged'            => $paged,
            'post_type'        => 'petition',
            'orderby'          => 'petition_sign',
            'order'            => 'DESC',
            'post_status'      => 'publish' );

        if ($category != '') {
            $category = explode(',', $category);
            $categories = array();
            foreach ($category as $id_slug) {
                $id_slug = str_replace(' ', '', $id_slug);
                $term = get_term_by('slug', $id_slug, 'petition_category');
                if (!$term) {
                    $term = get_term_by('id', $id_slug, 'petition_category');
                }
                array_push($categories, $term->term_id);
            }

            $args['tax_query'] = array(
                'relation' => 'OR',
                array(
                    'taxonomy' => 'petition_category',
                    'terms'    => $categories,
                )
            );
        }

        $args['meta_query'] = array('relation' => 'AND');

        if ($minimum_signature != 0) {
            array_push($args['meta_query'], array(
                'key'     => 'petition_sign',
                'value'   => $minimum_signature,
                'type'    => 'NUMERIC',
                'compare' => '>='
            ));
        }
            array_push($args['meta_query'], array(
                'key'     => 'petition_status',
                'value'   => '2',
                'compare' => '!='
            ));

        $posts = new WP_Query($args);

        $return_string = conikal_shortcode_loop_petition($posts, $attrs, $content);

        wp_reset_postdata();
        wp_reset_query();
        return $return_string;
    }
endif;


// interact with visual composer

add_action( 'vc_before_init', 'conikal_vc_popular_petitions_shortcode' );
function conikal_vc_popular_petitions_shortcode() {
   vc_map( array(
      "name" => esc_html__('Popular Petitions', 'campoal-tapo'),
      "base" => 'popular_petitions',
      "class" => '',
      "category" => esc_html__('Campoal', 'campoal-tapo'),
      'admin_enqueue_js' => plugin_dir_url( __FILE__ ) . 'vc_extend/bartag.js',
      'admin_enqueue_css' => plugin_dir_url( __FILE__ ) . 'vc_extend/bartag.css',
      "icon" => plugin_dir_url( __FILE__ ) . 'images/campoal-icon.svg',
      "params" => array(
        array(
            "type" => 'textfield',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Title', 'campoal-tapo'),
            "param_name" => 'title',
            "value" => 'Popular Petitions',
            "description" => esc_html__('Title of Segment', 'campoal-tapo')
        ),
        array(
            "type" => 'textfield',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Show Number', 'campoal-tapo'),
            "param_name" => 'show',
            "value" => 4,
            "description" => esc_html__('Number of Petitions', 'campoal-tapo')
        ),
        array(
            "type" => 'textfield',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Category IDs or Slugs (separated by comma)', 'campoal-tapo'),
            "param_name" => 'category',
            "value" => '',
            "description" => esc_html__('Category ID or Slugs comma-separated list of IDs (this or any children)', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Style', 'campoal-tapo'),
            "param_name" => 'style',
            "value" => array(
                'Grid' => 'grid',
                'List' => 'list'
                ),
            "std" => 'grid',
            "description" => esc_html__('Style Display of Petition', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Carousel Mode', 'campoal-tapo'),
            "param_name" => 'carousel',
            "value" => array(
                'No' => 'no',
                'Yes' => 'yes',
                ),
            "std" => 'no',
            "description" => esc_html__('Display petitions in carousel style', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Column', 'campoal-tapo'),
            "param_name" => 'column',
            "value" => conikal_shortcode_column_options(),
            "std" => 'four',
            "description" => esc_html__('Column of Petitions', 'campoal-tapo')
        ),
      )
   ) );
}

?>